{
 "cells": [
  {
   "cell_type": "code",
   "execution_count": 1,
   "id": "cc3ba2a8",
   "metadata": {},
   "outputs": [],
   "source": [
    "import csv, sys\n",
    "import io, textwrap, itertools\n",
    "from Bio import SeqIO\n",
    "from Bio.Seq import Seq\n",
    "from Bio.SeqRecord import SeqRecord\n",
    "csv.field_size_limit(sys.maxsize)\n",
    "common_amino_acid_set = set(['R', 'X', 'S', 'G', 'W', 'I', 'Q', 'A', 'T', 'V', 'K', 'Y', 'C', 'N', 'L', 'F', 'D', 'M', 'P', 'H', 'E'])\n",
    "\n",
    "\n",
    "def clean_seq(protein_id, seq):\n",
    "    seq = seq.upper()\n",
    "    new_seq = \"\"\n",
    "    has_invalid_char = False\n",
    "    invalid_char_set = set()\n",
    "    for ch in seq:\n",
    "        if 'A' <= ch <= 'Z' and ch not in ['J']:\n",
    "            new_seq += ch\n",
    "        else:\n",
    "            invalid_char_set.add(ch)\n",
    "            has_invalid_char = True\n",
    "    if has_invalid_char:\n",
    "        print(\"id: %s. Seq: %s\" % (protein_id, seq))\n",
    "        print(\"invalid char set:\", invalid_char_set)\n",
    "    return new_seq\n",
    "\n",
    "\n",
    "def file_reader(filename, header=True, header_filter=True):\n",
    "    if filename.endswith(\".fa\") or filename.endswith(\".fas\") or filename.endswith(\".fasta\"):\n",
    "        return fasta_reader(filename)\n",
    "    elif filename.endswith(\".csv\"):\n",
    "        return csv_reader(filename, header=True, header_filter=True)\n",
    "    elif filename.endswith(\".tsv\"):\n",
    "        return tsv_reader(filename, header=True, header_filter=True)\n",
    "    else:\n",
    "        return txt_reader(filename, header=header, header_filter=header_filter)\n",
    "\n",
    "\n",
    "def txt_reader(handle, header=True, header_filter=True):\n",
    "    '''\n",
    "    csv 读取器，适合大文件\n",
    "    :param handle:\n",
    "    :param header:\n",
    "    :param header_filter: 返回结果是否去掉头\n",
    "    :return:\n",
    "    '''\n",
    "    handle = handle if isinstance(handle, io.TextIOWrapper) else open(handle, 'r')\n",
    "    try:\n",
    "        cnt = 0\n",
    "        for line in handle:\n",
    "            cnt += 1\n",
    "            if header and header_filter and cnt == 1:\n",
    "                continue\n",
    "            yield line.strip()\n",
    "    except Exception as e:\n",
    "        raise StopIteration\n",
    "    finally:\n",
    "        if not handle.closed:\n",
    "            handle.close()\n",
    "\n",
    "\n",
    "def tsv_reader(handle, header=True, header_filter=True):\n",
    "    '''\n",
    "    csv 读取器，适合大文件\n",
    "    :param handle:\n",
    "    :param header:\n",
    "    :param header_filter: 返回结果是否去掉头\n",
    "    :return:\n",
    "    '''\n",
    "    handle = handle if isinstance(handle, io.TextIOWrapper) else open(handle, 'r')\n",
    "    try:\n",
    "        reader = csv.reader(handle, delimiter=\"\\t\")\n",
    "        cnt = 0\n",
    "        for row in reader:\n",
    "            cnt += 1\n",
    "            if header and header_filter and cnt == 1:\n",
    "                continue\n",
    "            yield row\n",
    "    except Exception as e:\n",
    "        raise StopIteration\n",
    "    finally:\n",
    "        if not handle.closed:\n",
    "            handle.close()\n",
    "\n",
    "\n",
    "def csv_reader(handle, header=True, header_filter=True):\n",
    "    '''\n",
    "    csv 读取器，适合大文件\n",
    "    :param handle:\n",
    "    :param header:\n",
    "    :param header_filter: 返回结果是否去掉头\n",
    "    :return:\n",
    "    '''\n",
    "    handle = handle if isinstance(handle, io.TextIOWrapper) else open(handle, 'r')\n",
    "    try:\n",
    "        # data = csv.reader((line.replace('\\0','') for line in data_initial), delimiter=\",\")\n",
    "        # reader = csv.reader(handle)\n",
    "        reader = csv.reader((line.replace('\\0', '') for line in handle))\n",
    "        cnt = 0\n",
    "        for row in reader:\n",
    "            cnt += 1\n",
    "            if header and header_filter and cnt == 1:\n",
    "                continue\n",
    "            yield row\n",
    "    except Exception as e:\n",
    "        raise StopIteration\n",
    "    finally:\n",
    "        if not handle.closed:\n",
    "            handle.close()\n",
    "\n",
    "\n",
    "def txt_writer(dataset, handle, header=None):\n",
    "    '''\n",
    "    txt 写\n",
    "    :param dataset: 数据\n",
    "    :param handle: 文件\n",
    "    :param header: 头\n",
    "    :return:\n",
    "    '''\n",
    "    with open(handle, \"w\") as wfp:\n",
    "        if header:\n",
    "            if isinstance(header, list):\n",
    "                wfp.write(\",\".join(header) + \"\\n\")\n",
    "            else:\n",
    "                wfp.write(header + \"\\n\")\n",
    "        for row in dataset:\n",
    "            wfp.write(str(row) + \"\\n\")\n",
    "\n",
    "\n",
    "def csv_writer(dataset, handle, header):\n",
    "    '''\n",
    "    csv 写，适合大文件\n",
    "    :param dataset: 数据\n",
    "    :param handle: 文件\n",
    "    :param header: 头\n",
    "    :return:\n",
    "    '''\n",
    "    handle = handle if isinstance(handle, io.TextIOWrapper) else open(handle, 'w')\n",
    "    try:\n",
    "        writer = csv.writer(handle)\n",
    "        if header:\n",
    "            writer.writerow(header)\n",
    "        for row in dataset:\n",
    "            writer.writerow(row)\n",
    "    except Exception as e:\n",
    "        raise e\n",
    "    finally:\n",
    "        if not handle.closed:\n",
    "            handle.close()\n",
    "\n",
    "\n",
    "def fasta_reader(handle, width=None):\n",
    "    \"\"\"\n",
    "    Reads a FASTA file, yielding header, sequence pairs for each sequence recovered 适合大文件\n",
    "    args:\n",
    "        :handle (str, pathliob.Path, or file pointer) - fasta to read from\n",
    "        :width (int or None) - formats the sequence to have max `width` character per line.\n",
    "                               If <= 0, processed as None. If None, there is no max width.\n",
    "    yields:\n",
    "        :(header, sequence) tuples\n",
    "    returns:\n",
    "        :None\n",
    "    \"\"\"\n",
    "    FASTA_STOP_CODON = \"*\"\n",
    "\n",
    "    handle = handle if isinstance(handle, io.TextIOWrapper) else open(handle, 'r')\n",
    "    width = width if isinstance(width, int) and width > 0 else None\n",
    "    try:\n",
    "        header = None\n",
    "        for is_header, group in itertools.groupby(handle, lambda line: line.startswith(\">\")):\n",
    "            if is_header:\n",
    "                header = group.__next__().strip()\n",
    "            else:\n",
    "                seq = ''.join(line.strip() for line in group).strip().rstrip(FASTA_STOP_CODON)\n",
    "                if width is not None:\n",
    "                    seq = textwrap.fill(seq, width)\n",
    "                yield header, seq\n",
    "    except Exception as e:\n",
    "        raise StopIteration\n",
    "    finally:\n",
    "        if not handle.closed:\n",
    "            handle.close()\n",
    "\n",
    "\n",
    "def write_fasta(filepath, sequences):\n",
    "    '''\n",
    "    write fasta file\n",
    "    :param filepath: savepath\n",
    "    :param sequences: fasta sequence(each item: [id, seq])\n",
    "    :return:\n",
    "    '''\n",
    "\n",
    "    if sequences:\n",
    "        with open(filepath, \"w\") as output_handle:\n",
    "            if len(sequences[0]) > 1 and isinstance(sequences[0][0], str):\n",
    "                for row in sequences:\n",
    "                    protein_id = row[0]\n",
    "                    seq = row[1]\n",
    "                    sequence = SeqRecord(Seq(seq, None), id=protein_id[1:] if protein_id and protein_id[0] == \">\" else protein_id, description=\"\")\n",
    "                    SeqIO.write(sequence, output_handle, \"fasta\")\n",
    "            else:\n",
    "                for sequence in sequences:\n",
    "                    SeqIO.write(sequence, output_handle, \"fasta\")\n"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 2,
   "id": "ea7150d4",
   "metadata": {},
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "1025076\n",
      "1025076\n",
      "692206\n",
      "692206\n"
     ]
    }
   ],
   "source": [
    "# blast\n",
    "unchecked_blast = \"../Results/Blastp/blastp_init.ids.labels\"\n",
    "unchecked_blast_info = []\n",
    "unchecked_blast_set = set()\n",
    "checked_blast = \"../Results/Blastp/blastp_verified.ids.labels\"\n",
    "checked_blast_info = []\n",
    "checked_blast_set = set()\n",
    "for row in tsv_reader(unchecked_blast, header=True, header_filter=True):\n",
    "    seq_id = row[0]\n",
    "    if seq_id[0] == \">\":\n",
    "        seq_id = seq_id[1:]\n",
    "    unchecked_blast_info.append([seq_id, row[1]])\n",
    "    unchecked_blast_set.add(seq_id)\n",
    "print(len(unchecked_blast_info))\n",
    "print(len(unchecked_blast_set))\n",
    "for row in tsv_reader(checked_blast, header=True, header_filter=True):\n",
    "    seq_id = row[0]\n",
    "    if seq_id[0] == \">\":\n",
    "        seq_id = seq_id[1:]\n",
    "    checked_blast_info.append([seq_id, row[1]])\n",
    "    checked_blast_set.add(seq_id)\n",
    "print(len(checked_blast_info))\n",
    "print(len(checked_blast_set))"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 3,
   "id": "8f9a4832",
   "metadata": {},
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "2603796\n",
      "2586059\n",
      "2364031\n",
      "2364026\n",
      "17690\n"
     ]
    }
   ],
   "source": [
    "# kofamscan\n",
    "unchecked_kofamscan = \"../Results/KofamScan/kofamscan_init.ids.labels\"\n",
    "unchecked_kofamscan_info = []\n",
    "unchecked_kofamscan_set = set()\n",
    "unchecked_kofamscan_repeat = {}\n",
    "checked_kofamscan = \"../Results/KofamScan/kofamscan_verified.ids.labels\"\n",
    "checked_kofamscan_info = []\n",
    "checked_kofamscan_set = set()\n",
    "for row in tsv_reader(unchecked_kofamscan, header=True, header_filter=True):\n",
    "    seq_id = row[0]\n",
    "    if seq_id[0] == \">\":\n",
    "        seq_id = seq_id[1:]\n",
    "    unchecked_kofamscan_info.append([seq_id, row[1]])\n",
    "    if seq_id in unchecked_kofamscan_set:\n",
    "        if seq_id not in unchecked_kofamscan_repeat:\n",
    "            unchecked_kofamscan_repeat[seq_id] = 1\n",
    "        else:\n",
    "            unchecked_kofamscan_repeat[seq_id] += 1\n",
    "    else:\n",
    "        unchecked_kofamscan_set.add(seq_id)\n",
    "print(len(unchecked_kofamscan_info))\n",
    "print(len(unchecked_kofamscan_set))\n",
    "for row in tsv_reader(checked_kofamscan, header=True, header_filter=True):\n",
    "    seq_id = row[0]\n",
    "    if seq_id[0] == \">\":\n",
    "        seq_id = seq_id[1:]\n",
    "    checked_kofamscan_info.append([seq_id, row[1]])\n",
    "    checked_kofamscan_set.add(seq_id)\n",
    "print(len(checked_kofamscan_info))\n",
    "print(len(checked_kofamscan_set))\n",
    "print(len(unchecked_kofamscan_repeat))"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 6,
   "id": "66eccb0a",
   "metadata": {},
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "1031473\n",
      "1031473\n",
      "927371\n",
      "927371\n",
      "0\n"
     ]
    }
   ],
   "source": [
    "# PLMSearch\n",
    "unchecked_plmsearch = \"../Results/PLMSearch/plmsearch_init.ids.labels\"\n",
    "unchecked_plmsearch_info = []\n",
    "unchecked_plmsearch_set = set()\n",
    "unchecked_plmsearch_repeat = {}\n",
    "checked_plmsearch = \"../Results/PLMSearch/plmsearch_verified.ids.labels\"\n",
    "checked_plmsearch_info = []\n",
    "checked_plmsearch_set = set()\n",
    "for row in tsv_reader(unchecked_plmsearch, header=True, header_filter=True):\n",
    "    seq_id = row[0]\n",
    "    if seq_id[0] == \">\":\n",
    "        seq_id = seq_id[1:]\n",
    "    unchecked_plmsearch_info.append([seq_id, row[1]])\n",
    "    if seq_id in unchecked_plmsearch_set:\n",
    "        if seq_id not in unchecked_plmsearch_repeat:\n",
    "            unchecked_plmsearch_repeat[seq_id] = 1\n",
    "        else:\n",
    "            unchecked_plmsearch_repeat[seq_id] += 1\n",
    "    else:\n",
    "        unchecked_plmsearch_set.add(seq_id)\n",
    "print(len(unchecked_plmsearch_info))\n",
    "print(len(unchecked_plmsearch_set))\n",
    "for row in tsv_reader(checked_plmsearch, header=True, header_filter=True):\n",
    "    seq_id = row[0]\n",
    "    if seq_id[0] == \">\":\n",
    "        seq_id = seq_id[1:]\n",
    "    checked_plmsearch_info.append([seq_id, row[1]])\n",
    "    checked_plmsearch_set.add(seq_id)\n",
    "print(len(checked_plmsearch_info))\n",
    "print(len(checked_plmsearch_set))\n",
    "print(len(unchecked_plmsearch_repeat))"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 7,
   "id": "e340965d",
   "metadata": {},
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "1481237\n",
      "1481237\n",
      "1347010\n",
      "1347010\n",
      "134227\n",
      "134227\n"
     ]
    }
   ],
   "source": [
    "# lucapcycle v2\n",
    "unchecked_lucapcycle_v2 = \"../Results/LucaPCycleV2/lucapcycle_v2_init.csv\"\n",
    "unchecked_lucapcycle_v2_info = []\n",
    "unchecked_lucapcycle_v2_set = set()\n",
    "checked_lucapcycle_v2 = \"../Results/LucaPCycleV2/lucapcycle_v2_verified.ids.labels\"\n",
    "checked_lucapcycle_v2_info = []\n",
    "checked_lucapcycle_v2_set = set()\n",
    "unable_checked_lucapcycle_v2 = \"../Results/LucaPCycleV2/lucapcycle_v2_unverifiable.ids\"\n",
    "unable_checked_lucapcycle_v2_info = []\n",
    "unable_checked_lucapcycle_v2_set = set()\n",
    "for row in csv_reader(unchecked_lucapcycle_v2, header=True, header_filter=True):\n",
    "    seq_id = row[0]\n",
    "    if seq_id[0] == \">\":\n",
    "        seq_id = seq_id[1:]\n",
    "    unchecked_lucapcycle_v2_info.append([seq_id, row[1]])\n",
    "    unchecked_lucapcycle_v2_set.add(seq_id)\n",
    "print(len(unchecked_lucapcycle_v2_info))\n",
    "print(len(unchecked_lucapcycle_v2_set))\n",
    "for row in tsv_reader(checked_lucapcycle_v2, header=True, header_filter=True):\n",
    "    seq_id = row[0]\n",
    "    if seq_id[0] == \">\":\n",
    "        seq_id = seq_id[1:]\n",
    "    checked_lucapcycle_v2_info.append([seq_id, row[1]])\n",
    "    checked_lucapcycle_v2_set.add(seq_id)\n",
    "print(len(checked_lucapcycle_v2_info))\n",
    "print(len(checked_lucapcycle_v2_set))\n",
    "for row in tsv_reader(unable_checked_lucapcycle_v2, header=True, header_filter=True):\n",
    "    seq_id = row[0]\n",
    "    if seq_id[0] == \">\":\n",
    "        seq_id = seq_id[1:]\n",
    "    unable_checked_lucapcycle_v2_info.append(seq_id)\n",
    "    unable_checked_lucapcycle_v2_set.add(seq_id)\n",
    "print(len(unable_checked_lucapcycle_v2_info))\n",
    "print(len(unable_checked_lucapcycle_v2_set))"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 8,
   "id": "dbca65f5",
   "metadata": {},
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "1513141\n",
      "1513141\n",
      "1467180\n",
      "1467180\n",
      "45961\n",
      "45961\n"
     ]
    }
   ],
   "source": [
    "# lucapcycle v3\n",
    "unchecked_lucapcycle_v3 = \"../Results/LucaPCycleV3/lucapcycle_v3_init.csv\"\n",
    "unchecked_lucapcycle_v3_info = []\n",
    "unchecked_lucapcycle_v3_set = set()\n",
    "\n",
    "checked_lucapcycle_v3 = \"../Results/LucaPCycleV3/lucapcycle_v3_verified.csv\"\n",
    "checked_lucapcycle_v3_info = []\n",
    "checked_lucapcycle_v3_set = set()\n",
    "\n",
    "unable_checked_lucapcycle_v3 = \"../Results/LucaPCycleV3/lucapcycle_v3_unverifiable.csv\"\n",
    "unable_checked_lucapcycle_v3_info = []\n",
    "unable_checked_lucapcycle_v3_set = set()\n",
    "\n",
    "for row in csv_reader(unchecked_lucapcycle_v3, header=True, header_filter=True):\n",
    "    seq_id = row[0]\n",
    "    if seq_id[0] == \">\":\n",
    "        seq_id = seq_id[1:]\n",
    "    unchecked_lucapcycle_v3_info.append([seq_id, row[1]])\n",
    "    unchecked_lucapcycle_v3_set.add(seq_id)\n",
    "print(len(unchecked_lucapcycle_v3_info))\n",
    "print(len(unchecked_lucapcycle_v3_set))\n",
    "\n",
    "for row in csv_reader(checked_lucapcycle_v3, header=True, header_filter=True):\n",
    "    seq_id = row[0]\n",
    "    if seq_id[0] == \">\":\n",
    "        seq_id = seq_id[1:]\n",
    "    checked_lucapcycle_v3_info.append([seq_id, row[1]])\n",
    "    checked_lucapcycle_v3_set.add(seq_id)\n",
    "print(len(checked_lucapcycle_v3_info))\n",
    "print(len(checked_lucapcycle_v3_set))\n",
    "\n",
    "for row in csv_reader(unable_checked_lucapcycle_v3, header=True, header_filter=True):\n",
    "    seq_id = row[0]\n",
    "    if seq_id[0] == \">\":\n",
    "        seq_id = seq_id[1:]\n",
    "    unable_checked_lucapcycle_v3_info.append(seq_id)\n",
    "    unable_checked_lucapcycle_v3_set.add(seq_id)\n",
    "print(len(unable_checked_lucapcycle_v3_info))\n",
    "print(len(unable_checked_lucapcycle_v3_set))"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 10,
   "id": "35e59731",
   "metadata": {},
   "outputs": [],
   "source": [
    "unchecked_blast_fasta = []\n",
    "checked_blast_fasta = []\n",
    "\n",
    "unchecked_kofamscan_fasta = []\n",
    "checked_kofamscan_fasta = []\n",
    "unchecked_kofamscan_repeat_fasta = []\n",
    "\n",
    "unchecked_plmsearch_fasta = []\n",
    "checked_plmsearch_fasta = []\n",
    "unchecked_plmsearch_repeat_fasta = []\n",
    "\n",
    "unchecked_lucapcycle_v2_fasta = []\n",
    "checked_lucapcycle_v2_fasta = []\n",
    "unable_checked_lucapcycle_v2_fasta = []\n",
    "\n",
    "unchecked_lucapcycle_v3_fasta = []\n",
    "checked_lucapcycle_v3_fasta = []\n",
    "unable_checked_lucapcycle_v3_fasta = []\n",
    "\n",
    "filepaths = [\n",
    "    \"../inference_data/dRep95_QS50_bins_all_gene.faa\", \n",
    "    \"../inference_data/non-redundant_genes_renamed.faa\"\n",
    "]\n",
    "total_seqs = 0\n",
    "for filepath in filepaths:\n",
    "    for row in fasta_reader(filepath):\n",
    "        seq_id = row[0]\n",
    "        seq = row[1].strip().upper()\n",
    "        total_seqs += 1\n",
    "        if seq_id[0] == \">\":\n",
    "            seq_id = seq_id[1:]\n",
    "        # blast\n",
    "        if seq_id in unchecked_blast_set:\n",
    "            unchecked_blast_fasta.append([seq_id, seq])\n",
    "        if seq_id in checked_blast_set:\n",
    "            checked_blast_fasta.append([seq_id, seq])\n",
    "            \n",
    "        # kofamscan\n",
    "        if seq_id in unchecked_kofamscan_set:\n",
    "            unchecked_kofamscan_fasta.append([seq_id, seq])\n",
    "        if seq_id in checked_kofamscan_set:\n",
    "            checked_kofamscan_fasta.append([seq_id, seq])\n",
    "            \n",
    "        # plmsearch\n",
    "        if seq_id in unchecked_plmsearch_set:\n",
    "            unchecked_plmsearch_fasta.append([seq_id, seq])\n",
    "        if seq_id in checked_plmsearch_set:\n",
    "            checked_plmsearch_fasta.append([seq_id, seq])\n",
    "            \n",
    "        # lucapcycle v2\n",
    "        if seq_id in unchecked_lucapcycle_v2_set:\n",
    "            unchecked_lucapcycle_v2_fasta.append([seq_id, seq])\n",
    "        if seq_id in checked_lucapcycle_v2_set:\n",
    "            checked_lucapcycle_v2_fasta.append([seq_id, seq])\n",
    "        if seq_id in unable_checked_lucapcycle_v2_set:\n",
    "            unable_checked_lucapcycle_v2_fasta.append([seq_id, seq])\n",
    "            \n",
    "        # lucapcycle v3\n",
    "        if seq_id in unchecked_lucapcycle_v3_set:\n",
    "            unchecked_lucapcycle_v3_fasta.append([seq_id, seq])\n",
    "        if seq_id in checked_lucapcycle_v3_set:\n",
    "            checked_lucapcycle_v3_fasta.append([seq_id, seq])\n",
    "        if seq_id in unable_checked_lucapcycle_v3_set:\n",
    "            unable_checked_lucapcycle_v3_fasta.append([seq_id, seq])\n",
    "            \n",
    "        if seq_id in unchecked_kofamscan_repeat:\n",
    "            for _ in range(unchecked_kofamscan_repeat[seq_id]):\n",
    "                unchecked_kofamscan_repeat_fasta.append([seq_id, seq])\n",
    "unchecked_kofamscan_fasta = unchecked_kofamscan_fasta + unchecked_kofamscan_repeat_fasta"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 12,
   "id": "b27336bc",
   "metadata": {},
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "total_seqs: 151187265\n",
      "blast:\n",
      "unchecked_blast_fasta: 1025076\n",
      "checked_blast_fasta: 692206\n",
      "\n",
      "kofamscan:\n",
      "unchecked_kofamscan_repeat_fasta: 17737\n",
      "unchecked_kofamscan_fasta: 2603796\n",
      "checked_kofamscan_fasta: 2364026\n",
      "\n",
      "plmsearch:\n",
      "unchecked_plmsearch_repeat_fasta: 0\n",
      "unchecked_plmsearch_repeat_fasta: 1031473\n",
      "unchecked_plmsearch_repeat_fasta: 927371\n",
      "\n",
      "lucapcycle_v2:\n",
      "unchecked_lucapcycle_v2_fasta: 1481237\n",
      "checked_lucapcycle_v2_fasta: 1347010\n",
      "unable_checked_lucapcycle_v2_fasta: 134227\n",
      "\n",
      "lucapcycle_v3:\n",
      "unchecked_lucapcycle_v3_fasta: 1513141\n",
      "checked_lucapcycle_v3_fasta: 1467180\n",
      "unable_checked_lucapcycle_v3_fasta: 45961\n"
     ]
    }
   ],
   "source": [
    "print(\"total_seqs: %d\" % total_seqs)   \n",
    "print(\"blast:\")\n",
    "print(\"unchecked_blast_fasta: %d\" % len(unchecked_blast_fasta))\n",
    "print(\"checked_blast_fasta: %d\" % len(checked_blast_fasta))\n",
    "\n",
    "print()\n",
    "print(\"kofamscan:\")\n",
    "print(\"unchecked_kofamscan_repeat_fasta: %d\" % len(unchecked_kofamscan_repeat_fasta))\n",
    "print(\"unchecked_kofamscan_fasta: %d\" % len(unchecked_kofamscan_fasta))\n",
    "print(\"checked_kofamscan_fasta: %d\" % len(checked_kofamscan_fasta))\n",
    "\n",
    "print()\n",
    "print(\"plmsearch:\")\n",
    "print(\"unchecked_plmsearch_repeat_fasta: %d\" % len(unchecked_plmsearch_repeat_fasta))\n",
    "print(\"unchecked_plmsearch_repeat_fasta: %d\" % len(unchecked_plmsearch_fasta))\n",
    "print(\"unchecked_plmsearch_repeat_fasta: %d\" % len(checked_plmsearch_fasta))\n",
    "\n",
    "print()\n",
    "print(\"lucapcycle_v2:\")\n",
    "print(\"unchecked_lucapcycle_v2_fasta: %d\" % len(unchecked_lucapcycle_v2_fasta))\n",
    "print(\"checked_lucapcycle_v2_fasta: %d\" % len(checked_lucapcycle_v2_fasta))\n",
    "print(\"unable_checked_lucapcycle_v2_fasta: %d\" % len(unable_checked_lucapcycle_v2_fasta))\n",
    "\n",
    "print()\n",
    "print(\"lucapcycle_v3:\")\n",
    "print(\"unchecked_lucapcycle_v3_fasta: %d\" % len(unchecked_lucapcycle_v3_fasta))\n",
    "print(\"checked_lucapcycle_v3_fasta: %d\" % len(checked_lucapcycle_v3_fasta))\n",
    "print(\"unable_checked_lucapcycle_v3_fasta: %d\" % len(unable_checked_lucapcycle_v3_fasta))\n",
    "\n",
    "write_fasta(\"../Results/Blastp/blastp_init.fasta\", unchecked_blast_fasta)\n",
    "write_fasta(\"../Results/Blastp/blastp_verified.fasta\", checked_blast_fasta)\n",
    "\n",
    "write_fasta(\"../Results/KofamScan/kofamscan_init.fasta\", unchecked_kofamscan_fasta)\n",
    "write_fasta(\"../Results/KofamScan/kofamscan_verified.fasta\", checked_kofamscan_fasta)\n",
    "\n",
    "write_fasta(\"../Results/PLMSearch/plmsearch_init.fasta\", unchecked_plmsearch_fasta)\n",
    "write_fasta(\"../Results/PLMSearch/plmsearch_verified.fasta\", checked_plmsearch_fasta)\n",
    "\n",
    "write_fasta(\"../Results/LucaPCycleV2/lucapcycle_v2_init.fasta\", unchecked_lucapcycle_v2_fasta)\n",
    "write_fasta(\"../Results/LucaPCycleV2/lucapcycle_v2_verified.fasta\", checked_lucapcycle_v2_fasta)\n",
    "write_fasta(\"../Results/LucaPCycleV2/lucapcycle_v2_unverifiable.fasta\", unable_checked_lucapcycle_v2_fasta)\n",
    "\n",
    "write_fasta(\"../Results/LucaPCycleV3/lucapcycle_v3_init.fasta\", unchecked_lucapcycle_v2_fasta)\n",
    "write_fasta(\"../Results/LucaPCycleV3/lucapcycle_v3_verified.fasta\", checked_lucapcycle_v2_fasta)\n",
    "write_fasta(\"../Results/LucaPCycleV3/lucapcycle_v3_unverifiable.fasta\", unable_checked_lucapcycle_v2_fasta)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "id": "b0ed8c6a",
   "metadata": {},
   "outputs": [],
   "source": []
  }
 ],
 "metadata": {
  "kernelspec": {
   "display_name": "Python 3 (ipykernel)",
   "language": "python",
   "name": "python3"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 3
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython3",
   "version": "3.9.13"
  }
 },
 "nbformat": 4,
 "nbformat_minor": 5
}
